@@ -5,8 +5,10 @@ import (
 	"context"
 	"encoding/json"
 	"io"
+	"maps"
 	"net/http"
 	"regexp"
+	"slices"
 	"strings"
 
 	"golang.org/x/sync/errgroup"
@@ -116,7 +118,7 @@ func (c *CustomRegexWebhook) FromData(ctx context.Context, verify bool, data []b
 
 MatchLoop:
 	for _, match := range matches {
-		for _, values := range match {
+		for key, values := range match {
 			// attempt to use capture group
 			secret := values[0]
 			if len(values) > 1 {
@@ -150,6 +152,26 @@ MatchLoop:
 					continue MatchLoop
 				}
 			}
+
+			if validations := c.GetValidations(); validations != nil {
+				validationRules := []struct {
+					enabled   bool
+					validator func(string) bool
+				}{
+					{validations[key].GetContainsDigit(), ContainsDigit},
+					{validations[key].GetContainsLowercase(), ContainsLowercase},
+					{validations[key].GetContainsUppercase(), ContainsUppercase},
+					{validations[key].GetContainsSpecialChar(), ContainsSpecialChar},
+				}
+
+				for _, rule := range validationRules {
+					if rule.enabled && !rule.validator(secret) {
+						// skip this match if a validation rule is enabled but missing from the secret
+						continue MatchLoop
+					}
+				}
+			}
+
 		}
 
 		g.Go(func() error {
@@ -194,7 +216,8 @@ func (c *CustomRegexWebhook) createResults(ctx context.Context, match map[string
 	}
 
 	var raw string
-	for key, values := range match {
+	for _, key := range slices.Sorted(maps.Keys(match)) {
+		values := match[key]
 		// values[0] contains the entire regex match.
 		secret := values[0]
 		if len(values) > 1 {
