@@ -2,10 +2,12 @@ package atlassian
 
 import (
 	"context"
+	"testing"
+
 	"github.com/google/go-cmp/cmp"
+	"github.com/stretchr/testify/require"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/engine/ahocorasick"
-	"testing"
 )
 
 func TestAtlassian_Pattern(t *testing.T) {
@@ -17,9 +19,27 @@ func TestAtlassian_Pattern(t *testing.T) {
 		want  []string
 	}{
 		{
-			name:  "typical pattern",
-			input: "atlassian = 'aB1cD2eF3gH4iJ5kL6mN7oP8'",
-			want:  []string{"aB1cD2eF3gH4iJ5kL6mN7oP8"},
+			name: "valid pattern",
+			input: `
+				[INFO] Sending request to the atlassian API
+				[DEBUG] Using Key=aB1cD2eF3gH4iJ5kL6mN7oP8
+				[INFO] Response received: 200 OK
+			`,
+			want: []string{"aB1cD2eF3gH4iJ5kL6mN7oP8"},
+		},
+		{
+			name: "valid pattern - xml",
+			input: `
+				<com.cloudbees.plugins.credentials.impl.StringCredentialsImpl>
+  					<scope>GLOBAL</scope>
+  					<id>{atlassian}</id>
+  					<secret>{AQAAABAAA r6RkiQao3PgqY9MOKtonpJdU}</secret>
+  					<description>configuration for production</description>
+					<creationDate>2023-05-18T14:32:10Z</creationDate>
+  					<owner>jenkins-admin</owner>
+				</com.cloudbees.plugins.credentials.impl.StringCredentialsImpl>
+			`,
+			want: []string{"r6RkiQao3PgqY9MOKtonpJdU"},
 		},
 	}
 
@@ -27,22 +47,15 @@ func TestAtlassian_Pattern(t *testing.T) {
 		t.Run(test.name, func(t *testing.T) {
 			matchedDetectors := ahoCorasickCore.FindDetectorMatches([]byte(test.input))
 			if len(matchedDetectors) == 0 {
-				t.Errorf("keywords '%v' not matched by: %s", d.Keywords(), test.input)
+				t.Errorf("test %q failed: expected keywords %v to be found in the input", test.name, d.Keywords())
 				return
 			}
 
 			results, err := d.FromData(context.Background(), false, []byte(test.input))
-			if err != nil {
-				t.Errorf("error = %v", err)
-				return
-			}
+			require.NoError(t, err)
 
 			if len(results) != len(test.want) {
-				if len(results) == 0 {
-					t.Errorf("did not receive result")
-				} else {
-					t.Errorf("expected %d results, only received %d", len(test.want), len(results))
-				}
+				t.Errorf("mismatch in result count: expected %d, got %d", len(test.want), len(results))
 				return
 			}
 
@@ -54,6 +67,7 @@ func TestAtlassian_Pattern(t *testing.T) {
 					actual[string(r.Raw)] = struct{}{}
 				}
 			}
+
 			expected := make(map[string]struct{}, len(test.want))
 			for _, v := range test.want {
 				expected[v] = struct{}{}
