@@ -9,20 +9,15 @@ import (
 	"time"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/stretchr/testify/require"
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/engine/ahocorasick"
 )
 
 var (
-	// TODO(kashif): Refactor the fake token generation if possible
-	validPattern   = generateRandomString() // this has the exact token string only which can be used in want too
-	validDomain    = "QHHPu7VPj.sI.auth0.com"
-	invalidPattern = `
-		auth0_credentials:
-			apiToken: eywT2nGMZwOcbsUVBwfiRPEl8P_wnmo6XfdUoGVwxDfOSjNyqhYqFdi.KojZZOM8Ox
-			domain: QHHPu7VPj.sI.auth0.com
-	`
+	// TODO: Refactor the fake token generation if possible
+	validPattern = generateRandomString() // this has the exact token string only which can be used in want too
 )
 
 func TestAuth0ManagementApitToken_Pattern(t *testing.T) {
@@ -36,13 +31,17 @@ func TestAuth0ManagementApitToken_Pattern(t *testing.T) {
 	}{
 		{
 			name:  "valid pattern",
-			input: makeFakeTokenString(validPattern, validDomain),
-			want:  []string{validPattern + validDomain},
+			input: makeFakeTokenString(validPattern, "Truffle-security.org.auth0.com"),
+			want:  []string{validPattern + "Truffle-security.org.auth0.com"},
 		},
 		{
-			name:  "invalid pattern",
-			input: invalidPattern,
-			want:  nil,
+			name: "invalid pattern",
+			input: `
+				auth0_credentials:
+					apiToken: eywT2nGMZwOcbsUVBwfiRPEl8P_wnmo6XfdUoGVwxDfOSjNyqhYqFdi.KojZZOM8Ox
+					domain: Truffle-security.org.auth0.com
+				`,
+			want: nil,
 		},
 	}
 
@@ -50,22 +49,15 @@ func TestAuth0ManagementApitToken_Pattern(t *testing.T) {
 		t.Run(test.name, func(t *testing.T) {
 			matchedDetectors := ahoCorasickCore.FindDetectorMatches([]byte(test.input))
 			if len(matchedDetectors) == 0 {
-				t.Errorf("keywords '%v' not matched by: %s", d.Keywords(), test.input)
+				t.Errorf("test %q failed: expected keywords %v to be found in the input", test.name, d.Keywords())
 				return
 			}
 
 			results, err := d.FromData(context.Background(), false, []byte(test.input))
-			if err != nil {
-				t.Errorf("error = %v", err)
-				return
-			}
+			require.NoError(t, err)
 
 			if len(results) != len(test.want) {
-				if len(results) == 0 {
-					t.Errorf("did not receive result")
-				} else {
-					t.Errorf("expected %d results, only received %d", len(test.want), len(results))
-				}
+				t.Errorf("mismatch in result count: expected %d, got %d", len(test.want), len(results))
 				return
 			}
 
@@ -77,6 +69,7 @@ func TestAuth0ManagementApitToken_Pattern(t *testing.T) {
 					actual[string(r.Raw)] = struct{}{}
 				}
 			}
+
 			expected := make(map[string]struct{}, len(test.want))
 			for _, v := range test.want {
 				expected[v] = struct{}{}
@@ -94,21 +87,26 @@ func makeFakeTokenString(token, domain string) string {
 	return fmt.Sprintf("auth0:\n apiToken: %s \n domain: %s", token, domain)
 }
 
-// generateRandomString generates exactly 2001 char string for a fake token to by pass the check in detector for testing
+// generateRandomString generates exactly 2001 char string for a fake token to pass the check in detector for testing
 func generateRandomString() string {
 	const length = 2001
-	const charset = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789._-"
+	const charset = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_"
+	const charsetWithBoundaryChars = charset + ".-"
 
 	random := rand.New(rand.NewSource(time.Now().UnixNano()))
 
 	var builder strings.Builder
 	builder.Grow(length)
 
-	for i := 0; i < length; i++ {
-		randomChar := charset[random.Intn(len(charset))]
+	for i := 0; i < length-1; i++ {
+		randomChar := charsetWithBoundaryChars[random.Intn(len(charset))]
 		builder.WriteByte(randomChar)
 	}
 
+	// ensure last character is not boundary character
+	lastChar := charset[random.Intn(len(charset))]
+	builder.WriteByte(lastChar)
+
 	// append ey in start as the token must start with 'ey'
 	return fmt.Sprintf("ey%s", builder.String())
 }
