@@ -51,21 +51,12 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	userIdMatches := userIdPat.FindAllStringSubmatch(dataStr, -1)
 
 	for _, userIdMatch := range userIdMatches {
-		if len(userIdMatch) != 2 {
-			continue
-		}
 		resUserIdMatch := strings.TrimSpace(userIdMatch[1])
 
 		for _, keyMatch := range keyMatches {
-			if len(keyMatch) != 2 {
-				continue
-			}
 			resKeyMatch := strings.TrimSpace(keyMatch[1])
 
 			for _, secretMatch := range secretMatches {
-				if len(secretMatch) != 2 {
-					continue
-				}
 				resSecretMatch := strings.TrimSpace(secretMatch[1])
 
 				s1 := detectors.Result{
