@@ -41,16 +41,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	matches := keyPat.FindAllStringSubmatch(dataStr, -1)
 
 	for _, accMatch := range accMatches {
-
-		if len(accMatch) != 2 {
-			continue
-		}
 		resAccMatch := strings.TrimSpace(accMatch[1])
 
 		for _, match := range matches {
-			if len(match) != 2 {
-				continue
-			}
 			resMatch := strings.TrimSpace(match[1])
 
 			s1 := detectors.Result{
