@@ -43,15 +43,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	urlMatches := baseURL.FindAllStringSubmatch(dataStr, -1)
 
 	for _, match := range matches {
-		if len(match) != 2 {
-			continue
-		}
 		resMatch := strings.TrimSpace(match[1])
 
 		for _, urlMatch := range urlMatches {
-			if len(urlMatch) != 2 {
-				continue
-			}
 			resURLMatch := strings.TrimSpace(urlMatch[1])
 
 			u, err := detectors.ParseURLAndStripPathAndParams(resURLMatch)
