@@ -100,6 +100,12 @@ func (p *PlainPrinter) Print(_ context.Context, r *detectors.ResultWithMetadata)
 	for _, k := range aggregateDataKeys {
 		printer.Printf("%s: %v\n", cases.Title(language.AmericanEnglish).String(k), aggregateData[k])
 	}
+
+	// if analysis info is not nil, means the detector added key for analyzer and result is verified
+	if r.Result.AnalysisInfo != nil && r.Result.Verified {
+		printer.Printf("Analyze: Run `trufflehog analyze` to analyze this key's permissions\n")
+	}
+
 	fmt.Println("")
 	return nil
 }
@@ -111,9 +117,9 @@ func structToMap(obj any) (m map[string]map[string]any, err error) {
 	}
 	err = json.Unmarshal(data, &m)
 	// Due to PostmanLocationType protobuf field being an enum, we want to be able to assign the string value of the enum to the field without needing to create another Protobuf field.
-	// To have the "UNKNOWN_POSTMAN = 0" value be assigned correctly to the field, we need to check if the Postman workspace ID is filled since every secret in the Postman source
-	// should have a valid workspace ID and the 0 value is considered nil for integers.
-	if m["Postman"]["workspace_uuid"] != nil {
+	// To have the "UNKNOWN_POSTMAN = 0" value be assigned correctly to the field, we need to check if the Postman workspace ID or collection ID is filled since every secret
+	// in the Postman source should have a valid workspace ID or collection ID and the 0 value is considered nil for integers.
+	if m["Postman"]["workspace_uuid"] != nil || m["Postman"]["collection_id"] != nil {
 		if m["Postman"]["location_type"] == nil {
 			m["Postman"]["location_type"] = source_metadatapb.PostmanLocationType_UNKNOWN_POSTMAN.String()
 		} else {
