@@ -15,6 +15,7 @@ import (
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/common"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/context"
+	"github.com/trufflesecurity/trufflehog/v3/pkg/feature"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/handlers"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/source_metadatapb"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/sourcespb"
@@ -25,14 +26,15 @@ import (
 const SourceType = sourcespb.SourceType_SOURCE_TYPE_FILESYSTEM
 
 type Source struct {
-	name        string
-	sourceId    sources.SourceID
-	jobId       sources.JobID
-	concurrency int
-	verify      bool
-	paths       []string
-	log         logr.Logger
-	filter      *common.Filter
+	name         string
+	sourceId     sources.SourceID
+	jobId        sources.JobID
+	concurrency  int
+	verify       bool
+	paths        []string
+	log          logr.Logger
+	filter       *common.Filter
+	skipBinaries bool
 	sources.Progress
 	sources.CommonSourceUnitUnmarshaller
 }
@@ -71,6 +73,7 @@ func (s *Source) Init(aCtx context.Context, name string, jobId sources.JobID, so
 		return errors.WrapPrefix(err, "error unmarshalling connection", 0)
 	}
 	s.paths = append(conn.Paths, conn.Directories...)
+	s.skipBinaries = conn.GetSkipBinaries()
 
 	filter, err := common.FilterFromFiles(conn.IncludePathsFile, conn.ExcludePathsFile)
 	if err != nil {
@@ -120,7 +123,12 @@ func (s *Source) Chunks(ctx context.Context, chunksChan chan *sources.Chunk, _ .
 func (s *Source) scanDir(ctx context.Context, path string, chunksChan chan *sources.Chunk) error {
 	workerPool := new(errgroup.Group)
 	workerPool.SetLimit(s.concurrency)
-	defer func() { _ = workerPool.Wait() }()
+	defer func() {
+		_ = workerPool.Wait()
+		s.ClearEncodedResumeInfoFor(path)
+	}()
+	startState := s.GetEncodedResumeInfoFor(path)
+	resuming := startState != ""
 
 	return fs.WalkDir(os.DirFS(path), ".", func(relativePath string, d fs.DirEntry, err error) error {
 		if err != nil {
@@ -147,10 +155,21 @@ func (s *Source) scanDir(ctx context.Context, path string, chunksChan chan *sour
 			return nil
 		}
 
+		if resuming {
+			// The start state holds the path that last completed
+			// scanning. When we find it, we can start scanning
+			// again on the next one.
+			if fullPath == startState {
+				resuming = false
+			}
+			return nil
+		}
+
 		workerPool.Go(func() error {
 			if err = s.scanFile(ctx, fullPath, chunksChan); err != nil {
 				ctx.Logger().Error(err, "error scanning file", "path", fullPath, "error", err)
 			}
+			s.SetEncodedResumeInfoFor(path, fullPath)
 			return nil
 		})
 
@@ -170,6 +189,12 @@ func (s *Source) scanFile(ctx context.Context, path string, chunksChan chan *sou
 		return skipSymlinkErr
 	}
 
+	// Check if file is binary and should be skipped
+	if (s.skipBinaries || feature.ForceSkipBinaries.Load()) && common.IsBinary(path) {
+		fileCtx.Logger().V(5).Info("skipping binary file", "path", path)
+		return nil
+	}
+
 	inputFile, err := os.Open(path)
 	if err != nil {
 		return fmt.Errorf("unable to open file: %w", err)
@@ -201,38 +226,16 @@ func (s *Source) scanFile(ctx context.Context, path string, chunksChan chan *sou
 // filepath or a directory.
 func (s *Source) Enumerate(ctx context.Context, reporter sources.UnitReporter) error {
 	for _, path := range s.paths {
-		fileInfo, err := os.Lstat(filepath.Clean(path))
+		_, err := os.Lstat(filepath.Clean(path))
 		if err != nil {
 			if err := reporter.UnitErr(ctx, err); err != nil {
 				return err
 			}
 			continue
 		}
-		if !fileInfo.IsDir() {
-			item := sources.CommonSourceUnit{ID: path}
-			if err := reporter.UnitOk(ctx, item); err != nil {
-				return err
-			}
-			continue
-		}
-		err = fs.WalkDir(os.DirFS(path), ".", func(relativePath string, d fs.DirEntry, err error) error {
-			if err != nil {
-				return reporter.UnitErr(ctx, err)
-			}
-			if d.IsDir() {
-				return nil
-			}
-			fullPath := filepath.Join(path, relativePath)
-			if s.filter != nil && !s.filter.Pass(fullPath) {
-				return nil
-			}
-			item := sources.CommonSourceUnit{ID: fullPath}
-			return reporter.UnitOk(ctx, item)
-		})
-		if err != nil {
-			if err := reporter.UnitErr(ctx, err); err != nil {
-				return err
-			}
+		item := sources.CommonSourceUnit{ID: path}
+		if err := reporter.UnitOk(ctx, item); err != nil {
+			return err
 		}
 	}
 	return nil
